==> base-domain-0.0.3-20170324.034038-112-sources.jar: com/thebeastshop/scm/po/Interest.java <==
package com.thebeastshop.scm.po;

import java.util.Date;

import pers.richard.ormybatis.domain.po.IdPo;

public class Interest extends IdPo {
	private String prodCode;
	private Integer isFreePost;
	private Date receiptStartTime;
	private Date receiptEndTime;
	private Date cashStartTime;
	private Date cashEndTime;
	private Date updateTime;
	private Date createTime;
	
	public Interest(){}
	
	public final static String
		F_PROD_CODE = "prod_code",
		F_IS_FREE_POST = "is_free_post",
		F_RECEIPT_START_TIME = "receipt_start_time",
		F_RECEIPT_END_TIME = "receipt_end_time",
		F_CASH_START_TIME = "cash_start_time",
		F_CASH_END_TIME = "cash_end_time",
		F_UPDATE_TIME = "update_time",
		F_CREATE_TIME = "create_time";
	

	public String getProdCode() {return prodCode;}
	public void setProdCode(String prodCode) {this.prodCode = prodCode;}

	public Integer getIsFreePost() {return isFreePost;}
	public void setIsFreePost(Integer isFreePost) {this.isFreePost = isFreePost;}

	public Date getReceiptStartTime() {return receiptStartTime;}
	public void setReceiptStartTime(Date receiptStartTime) {this.receiptStartTime = receiptStartTime;}

	public Date getReceiptEndTime() {return receiptEndTime;}
	public void setReceiptEndTime(Date receiptEndTime) {this.receiptEndTime = receiptEndTime;}

	public Date getCashStartTime() {return cashStartTime;}
	public void setCashStartTime(Date cashStartTime) {this.cashStartTime = cashStartTime;}

	public Date getCashEndTime() {return cashEndTime;}
	public void setCashEndTime(Date cashEndTime) {this.cashEndTime = cashEndTime;}

	public Date getUpdateTime() {return updateTime;}
	public void setUpdateTime(Date updateTime) {this.updateTime = updateTime;}

	public Date getCreateTime() {return createTime;}
	public void setCreateTime(Date createTime) {this.createTime = createTime;}
}

==> base-domain-0.0.3-20170420.121944-137-sources.jar: com/thebeastshop/scm/po/Interest.java <==
package com.thebeastshop.scm.po;

import java.util.Date;

import pers.richard.ormybatis.domain.po.IdPo;

public class Interest extends IdPo {
	/**
	 * @Field long serialVersionUID 
	 */
	private static final long serialVersionUID = 1L;
	
	private String prodCode;
	private Integer isFreePost;
	private Date receiptStartTime;
	private Date receiptEndTime;
	private Date cashStartTime;
	private Date cashEndTime;
	private Integer status;
	private Date updateTime;
	private Date createTime;
	
	public Interest(){}
	
	public final static String
		F_PROD_CODE = "prod_code",
		F_IS_FREE_POST = "is_free_post",
		F_RECEIPT_START_TIME = "receipt_start_time",
		F_RECEIPT_END_TIME = "receipt_end_time",
		F_CASH_START_TIME = "cash_start_time",
		F_CASH_END_TIME = "cash_end_time",
		F_STATUS = "status",
		F_UPDATE_TIME = "update_time",
		F_CREATE_TIME = "create_time";
	

	public String getProdCode() {return prodCode;}
	public void setProdCode(String prodCode) {this.prodCode = prodCode;}

	public Integer getIsFreePost() {return isFreePost;}
	public void setIsFreePost(Integer isFreePost) {this.isFreePost = isFreePost;}

	public Date getReceiptStartTime() {return receiptStartTime;}
	public void setReceiptStartTime(Date receiptStartTime) {this.receiptStartTime = receiptStartTime;}

	public Date getReceiptEndTime() {return receiptEndTime;}
	public void setReceiptEndTime(Date receiptEndTime) {this.receiptEndTime = receiptEndTime;}

	public Date getCashStartTime() {return cashStartTime;}
	public void setCashStartTime(Date cashStartTime) {this.cashStartTime = cashStartTime;}

	public Date getCashEndTime() {return cashEndTime;}
	public void setCashEndTime(Date cashEndTime) {this.cashEndTime = cashEndTime;}

	public Integer getStatus() {
		return status;
	}
	public void setStatus(Integer status) {
		this.status = status;
	}
	public Date getUpdateTime() {return updateTime;}
	public void setUpdateTime(Date updateTime) {this.updateTime = updateTime;}

	public Date getCreateTime() {return createTime;}
	public void setCreateTime(Date createTime) {this.createTime = createTime;}
}
